// Checker created by Nikolay Budin

#ifdef DEBUG
#  define _GLIBCXX_DEBUG
#endif
#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>
#include "testlib.h"
#define ff first
#define ss second
#define szof(x) ((int)x.size())
#ifndef LOCAL
#  define cerr __get_ce
#endif

using namespace std;
typedef long long ll;
typedef long double ld;
typedef pair<int, int> pii;
typedef unsigned long long ull;

using namespace __gnu_pbds;
template <typename T> using ordered_set = tree<T, null_type, less<T>, rb_tree_tag, tree_order_statistics_node_update>;
template <typename K, typename V> using ordered_map = tree<K, V, less<K>, rb_tree_tag, tree_order_statistics_node_update>;

int const INF = (int)1e9 + 1e3;
ll const INFL = (ll)1e18 + 1e6;

namespace parser {
string s;
int pos;

bool reached_end() {
	return pos == szof(s);
}

char get_char() {
	if (pos == szof(s)) {
		throw string("unexpected end of expression");
	}
	return s[pos];
}

void skip_char(char c) {
	if (pos == szof(s)) {
		throw format("unexpected end of expression (expected '%c')", c);
	}
	if (s[pos] != c) {
		throw format("unexpected character '%c' on position %d (expected '%c')", s[pos], pos + 1, c);
	}
	pos++;
}

void next_char() {
	if (pos == szof(s)) {
		throw string("unexpected end of expression");
	}
	++pos;
}

vector<set<char>> ops_on_lvl = {{'+', '-'}, {'*', '/'}};

int apply_op(int a, int b, char op) {
	if (op == '+') {
		return a + b;
	}
	if (op == '-') {
		return a - b;
	}
	if (op == '*') {
		return a * b;
	}
	if (op == '/') {
		if (b == 0 || a % b != 0) {
			throw format("trying to divide %d by %d", a, b);
		}
		return a / b;
	}
	assert(false);
}

int parse_unary();

int parse_binary(int lvl) {
	if (lvl == 2) {
		return parse_unary();
	}
	int ret = parse_binary(lvl + 1);
	while (!reached_end() && ops_on_lvl[lvl].count(get_char())) {
		char op = get_char();
		next_char();
		int val = parse_binary(lvl + 1);
		ret = apply_op(ret, val, op);
	}
	return ret;
}

int parse_unary() {
	if (reached_end()) {
		throw string("unexpected end of expression (expected '(', '-' or digit)");
	}
	if (get_char() == '(') {
		next_char();
		int ret = parse_binary(0);
		skip_char(')');
		return ret;
	}
	if (get_char() == '-') {
		next_char();
		return -parse_unary();
	}
	if ('0' <= get_char() && get_char() <= '9') {
		string num = "";
		while (!reached_end() && '0' <= get_char() && get_char() <= '9') {
			num += get_char();
			next_char();
		}
		if (szof(num) > 1 && num.front() == '0') {
			throw format("found number with leading zeroes: %s", num.c_str());
		}
		return stoi(num);
	}
	throw format("unexpected character '%c' on position %d (expected '(', '-' or digit)", get_char(), pos + 1);
}
}

int calc_expr(string const& expr) {
	parser::s = expr;
	parser::pos = 0;
	return parser::parse_binary(0);
}

pair<bool, string> check_outp(auto& stream, string const& num) {
	string s = stream.readLine();
	if (s == "No solution") {
		return {false, s};
	}

	for (char c : s) {
		stream.ensuref(('0' <= c && c <= '9') || c == '+' || c == '-' || c == '*' || c == '/' || c == '(' || c == ')', "incorrect character '%c'", c);
	}

	string digits_seq = "";
	for (char c : s) {
		if ('0' <= c && c <= '9') {
			digits_seq += c;
		}
	}

	if (digits_seq != num) {
		if (szof(s) > 20) {
			s.resize(20);
			s += "...";
		}
		stream.quitf(_wa, "ticket %s, sequence of digits in expression %s isn't equal to ticket number", num.c_str(), s.c_str());
	}

	try {
		int res = calc_expr(s);
		if (res != 100) {
			stream.quitf(_wa, "ticket %s, expression %s isn't equal to 100", num.c_str(), s.c_str());
		}
	} catch (string const& e) {
		if (szof(s) > 20) {
			s.resize(20);
			s += "...";
		}
		stream.quitf(_wa, "ticket %s, incorrect expression %s: %s", num.c_str(), s.c_str(), e.c_str());
	}

	return {true, s};
}

int main(int argc, char* argv[]) {
	setName("compare two outputs");
	registerTestlibCmd(argc, argv);

	int cnt_part = 0;
	int cnt_jury = 0;
	int tot_cnt = 0;

	while (!inf.seekEof()) {
		string num = inf.readLine();
		++tot_cnt;
		// cerr << "checking " << num << endl;

		auto j_res = check_outp(ans, num);
		auto p_res = check_outp(ouf, num);

		if (p_res.ff && !j_res.ff) {
			quitf(_fail, "ticket %s, jury didn't find solution, but it exists: %s", num.c_str(), p_res.ss.c_str());
		}

		if (j_res.ff) {
			++cnt_jury;
		}

		if (p_res.ff) {
			++cnt_part;
		}
	}

	if (tot_cnt == 1'000'000) {
		int score = -1;

		vector<pii> func_points = {{0, 0}, {5, 5}, {55, 10}, {555, 15}, {5555, 20}, {55555, 25}, 
			{cnt_jury - 55555, 75}, {cnt_jury - 5555, 80}, {cnt_jury - 555, 85}, {cnt_jury - 55, 90}, {cnt_jury - 5, 95}, {cnt_jury, 100}};

		// cerr << fixed;
		// for (int i = 0; i < szof(func_points) - 1; ++i) {
		// 	cerr << (func_points[i + 1].ss - func_points[i].ss) / (double) (func_points[i + 1].ff - func_points[i].ff) << endl;
		// }

		for (int i = 0; i < szof(func_points) - 1; ++i) {
			if (func_points[i].ff <=  cnt_part && cnt_part <= func_points[i + 1].ff) {
				score = func_points[i].ss + (ll) (cnt_part - func_points[i].ff) * (func_points[i + 1].ss - func_points[i].ss) / (func_points[i + 1].ff - func_points[i].ff);
				break;
			}
		}

		assert(0 <= score && score <= 100);

		quitp(score, "participant found %d out of %d expressions", cnt_part, cnt_jury);
	} else {
		if (cnt_part == cnt_jury) {
			quitf(_ok, "participant found all %d expressions", cnt_part);
		}
		quitf(_wa, "participant found %d out of %d expressions", cnt_part, cnt_jury);
	}

	return 0;
}